@@ -22,7 +22,7 @@ logging.basicConfig()
 log = logging.getLogger(__name__)
 
 
-def get_notification_url(usernasme=None):
+def get_notification_url(username=None):
     current_site = Site.objects.get_current()
     if current_site.domain == 'example.com':
         warnings.warn("You have not configured your Django sites framework, current site points to example.com")
